**Example 1: 查询数据库账号信息**



Input: 

```
tccli tdcpg DescribeAccounts --cli-unfold-argument  \
    --ClusterId tdcpg-xx
```

Output: 
```
{
    "Response": {
        "AccountSet": [],
        "TotalCount": 26,
        "RequestId": "03ea3f94-297d-11eb-8f30-525400b7dd5a"
    }
}
```

